Structs
- Heuristic
V1Score Plugin - Default heuristic scorer.
- Session
Score - Session
Score Registry - Runtime registry for session score plugins.
- Zero
V1Score Plugin - A deterministic scorer useful for testing and compatibility checks.
Enums
Constants
Traits
- Session
Score Plugin - A scoring plugin maps one session to one numeric score.