Structs
- Agent
- AI agent information
- Content
- Multimodal content container
- Event
- A single event in the flat timeline
- Session
- Top-level session - the root of a HAIL (Human AI Interaction Log) trace
- Session
Context - Session context metadata
- Stats
- Aggregate session statistics
Enums
- Content
Block - Individual content block
- Event
Type - Event type - the core abstraction
Constants
- ATTR_
LEGACY_ CALL_ ID - Legacy attribute key historically used for tool call correlation.
- ATTR_
SEMANTIC_ CALL_ ID - Canonical event attribute key for semantic tool call identifier.
- ATTR_
SEMANTIC_ GROUP_ ID - Canonical event attribute key for semantic group/turn identifier.
- ATTR_
SEMANTIC_ TOOL_ KIND - Canonical event attribute key for semantic tool kind classification.
- ATTR_
SOURCE_ RAW_ TYPE - Canonical event attribute key for source raw record type.
- ATTR_
SOURCE_ SCHEMA_ VERSION - Canonical event attribute key for source schema version.